@@ -3,17 +3,17 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20210630';
+our $VERSION = '0.20210730';
 
-# Table last modified: 2021-06-30
+# Table last modified: 2021-07-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
     '003' => '(?:8(?:5(?:20|58|77|8[0-258]|0[1-5]|3[01]|1[0159]|6[67])|6(?:[24]0|01|68|3[019]|1[02])|70[12]))',
-    '004' => '(?:8(?:5(?:[67]7|23|1[028]|[58][58]|3[0-3]|0[235])|6(?:[34]1|[68]6|29|0[23]|1[0-368])))',
+    '004' => '(?:8(?:5(?:[67]7|23|0[23]|1[028]|[58][58]|3[0-3])|6(?:[34]1|[68]6|29|0[23]|1[0-368])))',
     '005' => '(?:8(?:5(?:[58]5|01|43)|6(?:12|0[12])|798))',
     '006' => '(?:8(?:5(?:[58]5|61)|612))',
-    '007' => '(?:8(?:5(?:53|85|0[13578])|632))',
+    '007' => '(?:8(?:5(?:53|85|0[13578])|632|733))',
     '010' => '(?:(?:8(?:5(?:43|3[03]|2[05]|1[158]|6[045]|[58][08]|0[124-7]|7[0247])|6(?:[01]1|22|33|55|68|7[78])|794)|0(?:49[2-4]|[15]95)|1(?:49[23]|292)))',
     '011' => '(?:8(?:5(?:[58]5|01|20|77|1[01])|6(?:05|11|86)))',
     '012' => '(?:8(?:5(?:11|0[12])|6(?:51|0[14])))',
@@ -42,8 +42,8 @@ our %ZIP_TABLE = (
     '036' => '(?:(?:8(?:5(?:11|22|45|77|0[1-3]|6[0-47]|5[0158]|8[58]|3[038])|6(?:01|42|55|66|8[689])|7(?:77|88))|1(?:59[23]|393|492)|039[26]))',
     '037' => '(?:(?:86(?:01|55|86)|0392))',
     '038' => '(?:(?:3(?:19[2-5]|39[2-4]|[68]92|595)|85(?:[08]5|[56]0)|0(?:19[24]|292)|139[23]|279[23]))',
-    '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|49[23]|79[23]|[13]92|696)|0(?:19[58]|[28]92|595)|11(?:9[237]|8[0159])|4(?:29[23]|495|692)|3393))',
-    '040' => '(?:8(?:5(?:77|3[03]|4[13]|5[0-258]|2[02]|8[0158]|0[12]|1[0-2]|6[017])|6(?:55|70|4[02]|[68][068]|3[12]|0[1-359]|1[016])|7(?:[12][07])))',
+    '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|49[23]|79[23]|[13]92|696)|0(?:19[58]|59[25]|[28]92)|11(?:9[237]|8[0159])|4(?:29[23]|495|692)|3393))',
+    '040' => '(?:8(?:5(?:77|3[03]|4[13]|5[0-258]|2[02]|8[0158]|1[0-2]|0[125]|6[017])|6(?:55|70|4[02]|[68][068]|3[12]|0[1-359]|1[016])|7(?:[12][07])))',
     '041' => '(?:(?:8(?:5(?:01|40|77|2[23]|8[89]|1[0-25]|6[07]|5[1-8])|6(?:[23]3|48|55|80|1[01])|711)|1(?:19[2-6]|49[6-8]|[36]92)))',
     '042' => '(?:8(?:5(?:[01]1|55|67|8[58])|6(?:39|42|78)))',
     '043' => '(?:(?:8(?:5(?:58|60)|6(?:09|51))|0[45]95|1498))',
@@ -63,11 +63,11 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|5(?:[238]\d|4[1-9]|6[0135-9]|1[1-35-9]|7[02-9]|0[1-68]|5[0-46-9])|7(?:11|67|76|2[015]|9[15-7]|0[35-7])|406))',
-    '061' => '(?:(?:1(?:49[236-8]|39[2356]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
+    '060' => '(?:8(?:6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|5(?:[238]\d|4[1-9]|1[0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|7(?:11|67|76|2[015]|9[15-7]|0[35-7])|406))',
+    '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68]|5[56])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
-    '064' => '(?:8(?:5(?:2[1-46]|1[024-689]|6[0-7]|4[0-356]|5[014-8]|8[169]|0[23569]|7[0157]|3[035-7])|6(?:09|2[0-2489]|4[4589]|1[01]|3[039])|798))',
+    '064' => '(?:8(?:5(?:2[1-46]|1[024-689]|6[0-7]|4[0-356]|5[014-8]|8[169]|0[23569]|7[0157]|3[35-7])|6(?:09|2[0-2489]|4[4589]|1[01]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:0[19]|3[139]|1[0-2])))',
     '066' => '(?:8(?:5(?:20|33|1[025]|7[07]|6[67]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
     '067' => '(?:8(?:5(?:[05]1|47|85|6[45])|674))',
@@ -81,7 +81,7 @@ our %ZIP_TABLE = (
     '075' => '(?:8(?:50|71)1)',
     '076' => '(?:8(?:5(?:11|55)|6(?:09|66)|765))',
     '077' => '(?:(?:8(?:6(?:01|60|86)|5[01]1)|029[2356]))',
-    '078' => '(?:(?:1(?:79[235-7]|49[235]|39[35])|85(?:55|0[1-6]|1[013])|4(?:19[346-8]|492)|3(?:39[2-4]|792)|2(?:19[23]|692)|039[27]))',
+    '078' => '(?:(?:1(?:79[235-7]|49[235]|39[35])|85(?:55|1[013]|0[1-7])|4(?:19[346-8]|492)|3(?:39[2-4]|792)|2(?:19[23]|692)|039[27]))',
     '079' => '(?:(?:8(?:5(?:85|1[136]|5[05]|0[1357-9])|6(?:5[0-26]|1[0-3]))|0(?:39[2-47]|19[278]|59[235])|1(?:39[367]|192)))',
     '080' => '(?:(?:8(?:5(?:[67]0|0[1-3]|1[018]|8[58]|5[05]|3[18])|6(?:23|39|42|55|6[06]|0[19]|7[07]|8[068])|7(?:[01][18]))|1(?:49[23]|292)|249[235-8]|019[6-8]))',
     '081' => '(?:(?:029[2-5]|8501))',
@@ -103,20 +103,20 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|5[0-248]|6[05689]|1[01357-9]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[16]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|2[0147]|3[09]|[48][48])|0(?:19|66|8[06]|5[015]|7[07-9])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|5[0-248]|6[05689]|1[01357-9]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|2[0147]|3[09]|[48][48])|0(?:19|66|8[06]|5[015]|7[07-9])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-35689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[1-8]|3[013568]|1[013-7])|6(?:1[0-35-79]|8[28]|6[2578]|3[01346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|2[0146]|4[05]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:0[2359]|4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|7[03568]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1)|6060))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|5[158]|1[014-8]|8[1389]|4[25]|3[0-589]|7[014-9])|3(?:7[027-9]|1[0-3579]|2[458]|8[013689]|6[05]|5[0167]|0[1-7]|3[02358]|4[0-5])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|5[056]|0[124-8]|8[168]|4[02-489]|2[0-4679]|6[08]|1[05689])|2(?:22|40|1[0-258]|7[17]|3[38]|0[568]|8[0-589]|5[0-24-8]|6[026])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
     '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|6[014-689]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-589]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|8[015689]|2[01356]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|0[18]|2[0256]|3[069])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|0[2578]|7[27]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])))',
+    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|0[2578]|7[27]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])|797))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[03-58]|3[02369]|0[1-36-9]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|8[0-3568])|3(?:2[25689]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|7[23589]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|85|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|5[0589]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|8[02-468]|2[024])|6(?:2[0-2568]|6[0259]|5[34]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|6(?:4[028]|3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05])|7(?:[56]5|21|98|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[02-5])|5(?:7[0356]|4[018]|6[02369]|1[1246]|3[0138]|0[1-35689]|5[015-8]|2[48]|8[035])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
-    '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|6[0-3]|3[38]|5[04-8]|8[16]|1[0-2]|0[1-48])|7(?:01|1[0-29])|139|311))',
+    '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|8[16]|1[0-2]|0[1-48]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|7[147]|4[01356]|2[0-2468]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-46]|8[014-8]|4[0134689]|0[1-3578]|3[237])|6[12]1))',
@@ -211,7 +211,7 @@ our %ZIP_TABLE = (
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
     '230' => '(?:8(?:5(?:11|7[17]|0[14]|5[05])|6(?:[68]6|11|28)|765))',
-    '231' => '(?:8(?:3(?:07|3[0158]|2[0134]|4[036]|1[0-6])|5(?:49|6[26]|3[469]|8[58]|5[05]|2[08])|4(?:[368]4|45|7[78]|1[19])|6(?:16|60|5[24]|8[29])|7(?:7[12]|1[15])|00[18]|831|966))',
+    '231' => '(?:8(?:3(?:07|3[0158]|2[0134]|4[036]|1[0-6])|5(?:6[26]|3[469]|8[58]|5[05]|2[08]|4[49])|4(?:[368]4|45|7[78]|1[19])|6(?:16|60|5[24]|8[29])|7(?:7[12]|1[15])|00[18]|831|966))',
     '232' => '(?:8(?:5(?:31|8[057]|5[58]|1[05])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
     '235' => '(?:85(?:58|2[23]|0[15]))',
@@ -246,7 +246,7 @@ our %ZIP_TABLE = (
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
     '265' => '(?:8501)',
     '266' => '(?:8(?:550|733))',
-    '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:8[08]|9[25-8])|39[23])|85(?:[0-2]1|55)|019[24578]))',
+    '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:8[08]|9[25-8])|39[23])|85(?:[0-2]1|55)|019[24-8]))',
     '271' => '(?:8(?:5(?:01|22|3[03]|8[058]|1[0158]|5[0157]|6[02-4])|6(?:66|72|2[05])))',
     '272' => '(?:(?:85(?:01|73|4[03]|3[38]|5[058]|2[02]|8[0158]|1[0-468]|6[01])|019[35]))',
     '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|27)|7(?:10|33))|019[2357]))',
@@ -272,7 +272,7 @@ our %ZIP_TABLE = (
     '296' => '(?:(?:860[12]|0197))',
     '297' => '(?:(?:8(?:5(?:[01]1|33|67|88|5[058])|6(?:11|22|66))|0(?:19[2-8]|29[28])))',
     '298' => '(?:(?:029[25-7]|8501))',
-    '299' => '(?:(?:4(?:39[24-7]|[126]92|49[23])|0(?:29[235-8]|19[2458])|2(?:[1245]92|79[25])|5(?:29[25]|192)|119[245]))',
+    '299' => '(?:(?:4(?:39[24-7]|[126]92|49[23])|0(?:19[24-8]|29[235-8])|2(?:[1245]92|79[25])|5(?:29[25]|192)|119[245]))',
     '300' => '(?:(?:0(?:3(?:88|9[2-8])|19[235]|49[26]|59[35]|[67]92)|2(?:6(?:86|9[258])|49[2-578]|79[2357]|395|593)|1(?:29[24-6]|19[235]|[3-5]92|696)|8(?:5(?:50|67|88)|6(?:01|19|86))|4(?:29[35]|193|495|598)|3(?:59[258]|29[45])))',
     '301' => '(?:8(?:6(?:0[12]|1[01])|5(?:55|0[15])))',
     '302' => '(?:(?:85(?:0[12]|8[56])|0198))',
@@ -316,7 +316,7 @@ our %ZIP_TABLE = (
     '340' => '(?:(?:8(?:5(?:33|77|5[015]|2[04]|0[19]|8[58]|6[078]|1[01])|6(?:59|86|1[01]))|0(?:19[2-4]|295)))',
     '341' => '(?:85(?:01|5[058]|2[67]))',
     '342' => '(?:8(?:50[125]|601))',
-    '343' => '(?:(?:8(?:5(?:11|40|85|5[458]|0[12])|601)|019[23]))',
+    '343' => '(?:(?:8(?:5(?:[24]0|11|85|5[458]|0[12])|601)|019[23]))',
     '344' => '(?:8(?:5(?:11|40|55|66|7[78]|3[35]|8[58]|2[12]|0[68])|68[06]))',
     '345' => '(?:850[1248])',
     '346' => '(?:(?:8(?:5(?:[34]0|24|[01][16])|68[56])|01(?:8[13]|9[2-68])))',
@@ -628,7 +628,7 @@ our %ZIP_TABLE = (
     '662' => '(?:85(?:[34]3|10|21|67|8[056]|5[258]|0[1-35]))',
     '663' => '(?:8(?:5(?:[67]7|01|10|45|58|8[568])|601))',
     '664' => '(?:8(?:5(?:[58]8|33|2[02]|4[05]|0[1-3578]|1[01])|6(?:24|41|50|1[015])))',
-    '665' => '(?:8(?:5(?:01|43|67|8[58]|5[05])|665))',
+    '665' => '(?:8(?:5(?:01|43|67|5[058]|8[58])|665))',
     '666' => '(?:(?:0292|8501))',
     '667' => '(?:(?:8(?:555|651)|0198))',
     '668' => '(?:(?:8(?:6(?:66|5[05])|501)|0(?:29[238]|393)))',
@@ -691,7 +691,7 @@ our %ZIP_TABLE = (
     '729' => '(?:(?:3(?:19[238]|49[278]|592)|0(?:49[25]|292|393)|2(?:39[2-4]|292)|149[23]|4295|5792))',
     '730' => '(?:8(?:5(?:8[0235-9]|4[0-58]|6[1-35-7]|1[013-58]|5[0-289]|0[1-47-9]|7[015-7]|3[0-35689]|2[0-378])|6(?:7[02578]|4[1-36]|1[0-29]|8[067]|6[126-8]|5[0-8]|3[01]|2[026]|0[135689])|7(?:[23]0|87|0[1267]|9[4-8])))',
     '731' => '(?:(?:0(?:19[2-8]|29[235]|59[235]|692)|3(?:19[2-68]|39[358]|595)|4(?:39[236-8]|29[2-4])|1(?:59[57]|795)|519[35-8]|219[58]))',
-    '732' => '(?:8(?:5(?:55|80|6[4-6]|7[05]|1[0-2]|0[13-57-9])|7(?:65|91)|652))',
+    '732' => '(?:8(?:5(?:55|80|6[4-6]|7[05]|1[0-2]|0[13-57-9])|652|765))',
     '733' => '(?:8(?:6(?:89|3[03]|2[1-6]|4[1-36-8]|6[09]|7[0578]|0[18]|5[01]|1[016])|5(?:0[19]|4[0358]|5[0-358]|2[0158]|3[0135]|1[0-4])|701))',
     '734' => '(?:8(?:5(?:[37]0|22|43|58|6[07]|1[035])|798))',
     '735' => '(?:8(?:5(?:01|55|77|88|1[01])|6(?:70|86)))',
@@ -768,7 +768,7 @@ our %ZIP_TABLE = (
     '807' => '(?:(?:85(?:01|8[568]|5[56])|019[28]|1392))',
     '808' => '(?:(?:8(?:5(?:1[045]|5[058]|8[58]|0[125])|606)|0196))',
     '809' => '(?:8501)',
-    '810' => '(?:8(?:5(?:3[0-357-9]|1[1-9]|5[135-8]|7[01578]|2[0-578]|0[1-46-9]|8[13-57-9]|4[013-6]|6[0135-8])|6(?:8[035689]|4[28]|6[02-79]|7[035-7]|1[0179]|0[13-9]|2[0-2579]|5[0-6]|3[1346-9])|7(?:98|2[0-257]|3[14]|0[157]|1[06-8])))',
+    '810' => '(?:8(?:5(?:3[0-357-9]|1[1-9]|5[135-8]|7[01578]|2[0-578]|0[1-46-9]|8[13-57-9]|4[013-6]|6[0135-8])|6(?:8[035689]|4[28]|6[02-79]|7[03-7]|1[0179]|0[13-9]|2[0-2579]|5[0-6]|3[1346-9])|7(?:98|2[0-257]|3[14]|0[157]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[258]|49[256]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
     '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|2[0-24-689]|7[025-8]|5[0-79]|[14][0-8]|6[0-25689])|5(?:[23578]\d|0[1-9]|6[0-689]|[14][0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|55|68|1[39]|7[78]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
@@ -805,7 +805,7 @@ our %ZIP_TABLE = (
     '844' => '(?:8(?:6(?:16|25|0[12])|5(?:[58]5|01)))',
     '845' => '(?:85(?:01|1[01]))',
     '846' => '(?:8501)',
-    '847' => '(?:(?:8(?:5(?:11|88)|601)|0(?:19[23]|39[23])|1292))',
+    '847' => '(?:(?:8(?:5(?:11|55|88)|601)|0(?:19[23]|39[23])|1292))',
     '848' => '(?:(?:0492|8501))',
     '849' => '(?:(?:85(?:14|22|77|0[1-3]|[58][58])|1(?:39[2-4]|[14]92|698)|3(?:19[23]|29[23])|419[2-5]|239[235]|519[238]|059[27]))',
     '850' => '(?:8(?:5(?:2[0-35]|8[0568]|1[0-258]|7[057]|5[0158]|0[13-8]|6[0367]|3[0167]|4[013578])|6(?:22|45|50|7[78]|1[018]|6[268]|8[5-8]|0[236])))',
